@@ -4,20 +4,18 @@ import * as path from "path";
 
 const app = express();
 
-app.get("/app/*", (req, res) => {
+app.get("/app/{*splat}", (req, res) => {
   const newPath = req.path.replace("/app/", "/");
   res.redirect(301, `https://app.auto-editor.com${newPath}`);
 });
 
-app.get("/options", (req, res) => {
-  let options = {
-    headers: {"Content-Type": "text/html"}
-  };
-  res.sendFile(path.join(__dirname, "public/ref/options"), options);
+app.get("/blog", (req, res) => { res.redirect(301, `https://basswood-io.com/blog`) });
+app.get("/blog/{*splat}", (req, res) => {
+  res.redirect(301, `https://basswood-io.com${req.path}`);
 });
 
-app.get("/gpu", (req, res) => {
-  res.redirect("/docs/gpu")
+app.get("/options", (req, res) => {
+  res.redirect(301, "https://auto-editor.com/ref/options");
 });
 
 app.use(express.static("public", {
@@ -31,7 +29,10 @@ app.use(express.static("public", {
 }));
 
 app.use((req, res) => {
-  res.status(404).sendFile(path.join(__dirname, "404.html"));
+  let options = {
+    headers: {"Content-Type": "text/html"}
+  };
+  res.status(404).sendFile(path.join(__dirname, "public/404"), options);
 });
 
 app.listen(1337, (req, res) => console.log("running on http://localhost:1337"));
